nova-epics
==========

`nova-epics` is a Python package for retrieving unprivileged instrument status information from EPICS for use in NOVA applications.

You can install this package directly with

```commandline
pip install "nova-epics[trame]"
```

Developers: please read [this document](DEVELOPMENT.md)
